@@ -310,9 +310,15 @@ $(function(){
 		colHeaders: H
 	    });
 	} else {
-	    var i = 0;
+	    var headers = $("#INPUT").handsontable("getColHeader");
+	    var i = 0
 	    $.each(mydata.data, function(k, v) {
-		mydata.data[k] =
+		Object.defineProperty( // rename the data columns
+		    mydata.data, headers[i],
+		    Object.getOwnPropertyDescriptor(mydata.data, k)
+		);
+		delete mydata.data[k];
+		mydata.data[headers[i]] =
 		    $("#INPUT").handsontable('getDataAtCol',i++);
 	    });
 	}
@@ -766,6 +772,25 @@ $(function(){
 		$('.hide4KCa3').hide();
 		break;
 	    }
+	    switch (set.sister){
+	    case 42:
+		$('.show4Ca42').show();
+		$('.hide4Ca42').hide();
+		break;
+	    case 43:
+		$('.show4Ca43').show();
+		$('.hide4Ca43').hide();
+		break;
+	    case 44:
+		$('.show4Ca44').show();
+		$('.hide4Ca44').hide();
+		break;
+	    case 48:
+		$('.show4Ca48').show();
+		$('.hide4Ca48').hide();
+		break;
+	    }
+	    setKCaHeaders();
 	    break;
 	case 'Rb-Sr':
 	    $('.show4RbSr').show();
@@ -1244,8 +1269,15 @@ $(function(){
 	    break;
 	case 'K-Ca':
 	    setOption('#KCa-formats',set.format);
+	    setOption('#KCa-sister',set.sister);
+	    $('#Ca40Ca42').val(cst.iratio.Ca40Ca42[0]);
+	    $('#errCa40Ca42').val(cst.iratio.Ca40Ca42[1]);
+	    $('#Ca40Ca43').val(cst.iratio.Ca40Ca43[0]);
+	    $('#errCa40Ca43').val(cst.iratio.Ca40Ca43[1]);
 	    $('#Ca40Ca44').val(cst.iratio.Ca40Ca44[0]);
 	    $('#errCa40Ca44').val(cst.iratio.Ca40Ca44[1]);
+	    $('#Ca40Ca48').val(cst.iratio.Ca40Ca48[0]);
+	    $('#errCa40Ca48').val(cst.iratio.Ca40Ca48[1]);
 	    $('#LambdaK40').val(cst.lambda.K40[0]),
 	    $('#errLambdaK40').val(cst.lambda.K40[1]),
 	    $('#i2iKCa').prop('checked',set.i2i);
@@ -1670,10 +1702,17 @@ $(function(){
 	    cst.lambda.Th232[1] = getNumber("#errLambdaTh232");
 	    break;
 	case 'K-Ca':
+	    cst.iratio.Ca40Ca42[0] = getNumber('#Ca40Ca42');
+	    cst.iratio.Ca40Ca42[1] = getNumber('#errCa40Ca42');
+	    cst.iratio.Ca40Ca43[0] = getNumber('#Ca40Ca43');
+	    cst.iratio.Ca40Ca43[1] = getNumber('#errCa40Ca43');
 	    cst.iratio.Ca40Ca44[0] = getNumber('#Ca40Ca44');
 	    cst.iratio.Ca40Ca44[1] = getNumber('#errCa40Ca44');
+	    cst.iratio.Ca40Ca48[0] = getNumber('#Ca40Ca48');
+	    cst.iratio.Ca40Ca48[1] = getNumber('#errCa40Ca48');
 	    cst.lambda.K40[0] = getNumber("#LambdaK40");
 	    cst.lambda.K40[1] = getNumber("#errLambdaK40");
+	    gcsettings.sister = getInt('#KCa-sister');
 	    break;
 	case 'Rb-Sr':
 	    cst.iratio.Rb85Rb87[0] = getNumber('#Rb85Rb87');
@@ -2508,6 +2547,29 @@ $(function(){
 	    $("#helpmenu").dialog('option', 'title', helpTitle);
 	});
     }
+
+    function setKCaHeaders(){
+	var fmt = IsoplotR.settings["K-Ca"].format;
+	var sister = IsoplotR.settings["K-Ca"].sister;
+	var headers = $("#INPUT").handsontable("getColHeader");
+	switch (fmt){
+	case 1:
+	case 3:
+	    headers[0] = "K40/Ca"+sister;
+	    headers[1] = "err[K40/Ca"+sister+"]";
+	    headers[2] = "Ca40/Ca"+sister;
+	    headers[3] = "err[Ca40/Ca"+sister+"]";
+	    break;
+	case 2:
+	    headers[2] = "Ca"+sister+"/Ca40";
+	    headers[3] = "err[Ca"+sister+"/Ca40]";
+	    break;
+	}
+	$("#INPUT").data('handsontable').updateSettings({
+	    colHeaders: headers
+	});
+	handson2json();
+    }
     
     $.switchErr = function(){
 	IsoplotR.settings.ierr = getInt("#ierr");
@@ -2629,7 +2691,9 @@ $(function(){
 	observeChanges: true,
 	manualColumnResize: true,
 	outsideClickDeselects: false,
-	selectionMode: 'range'
+	selectionMode: 'range',
+	columnSorting: true,
+	sortIndicator: true
     });
 
     $("#OUTPUT").handsontable({
